@@ -97,7 +97,7 @@ class DankEncoder:
         :return: the byte sequence corresponding to n
         :rtype: bytes
         """
-        assert n < self.num_words(self.max_fixed_slice, self.max_fixed_slice)
+        assert n < self.num_words(self.fixed_slice, self.fixed_slice)
         return self._encoder.unrank(n)
 
     def rank(self, s: bytes) -> int:
